// src/utils/useHCesiumViewerCls.ts

import { HCesiumManager } from './managers/HCesiumManager'; // 导入新的 Manager

/**
 * 管理 HCesiumViewerManager 实例的生命周期。
 * @param containerId - Cesium Viewer 容器的 DOM ID。
 * @returns 返回包含 HCesiumViewerManager 实例的对象。
 */
export function useHCesiumViewerCls(containerId: string) {
  const hCesiumViewerManager = new HCesiumManager();
  // 可以在开发模式下暴露 manager 实例，方便调试
  if ($__DEV__) Object.assign(globalThis, { hCesiumViewerManager });

  onMounted(() => {
    hCesiumViewerManager.init(containerId);
  });

  onBeforeUnmount(() => {
    hCesiumViewerManager.destroy();
  });

  // 返回 Manager 实例，供其他 Composable 或组件使用
  return {
    hCesiumViewerManager,
  };
}
